@@ -190,9 +190,9 @@ class RotatingBackup:
             logger.info(f'Created SQLite dump of database `{name}` to `{destination}/{dump_filename}`')
 
         if self.is_postgresql(name):
-            with (gzip.open(f'{destination}/{dump_filename}', 'wb') as backup_file,
-                  PgEnvWrapper(settings.DATABASES[name]) as env):
-                popen = subprocess.Popen(['pg_dump'], env=env, stdout=subprocess.PIPE, universal_newlines=True)
+            with gzip.open(f'{destination}/{dump_filename}', 'wb') as backup_file:
+                with PgEnvWrapper(settings.DATABASES[name]) as env:
+                    popen = subprocess.Popen(['pg_dump'], env=env, stdout=subprocess.PIPE, universal_newlines=True)
 
                 for stdout_line in iter(popen.stdout.readline, ''):
                     backup_file.write(stdout_line.encode('utf-8'))
